@@ -22,18 +22,21 @@ import pkg_resources
 import pprint
 import re
 import site
+import struct
 import subprocess
 import sys
 import webbrowser
 
-try:
-    from xmlrpclib import Fault as XMLRPCFault
+if sys.version_info[0] == 2:
+    from httplib import HTTPException
     from urllib import urlretrieve
     from urlparse import urlparse
-except ImportError:
-    from xmlrpc.client import Fault as XMLRPCFault
+    from xmlrpclib import Fault as XMLRPCFault
+else:
+    from http.client import HTTPException
     from urllib.request import urlretrieve
     from urllib.parse import urlparse
+    from xmlrpc.client import Fault as XMLRPCFault
 
 from distutils.sysconfig import get_python_lib
 from yolk.metadata import get_metadata
@@ -44,6 +47,11 @@ from yolk.utils import run_command, command_successful
 from yolk.__init__ import __version__ as VERSION
 
 
+class YolkException(Exception):
+
+    """Exception for communicating top-level error to user."""
+
+
 class StdOut(object):
 
     """Filter stdout or stderr from specific modules So far this is just used
@@ -152,6 +160,12 @@ class Yolk(object):
             pkg_spec = self.options.pkg_spec
         self.pkg_spec = pkg_spec
 
+        if self.options.fields:
+            self.options.fields = [s.strip().lower()
+                                   for s in self.options.fields.split(',')]
+        else:
+            self.options.fields = []
+
         if (
             not self.options.pypi_search and
             len(sys.argv) == 1
@@ -356,32 +370,28 @@ class Yolk(object):
 
         """
         show_metadata = self.options.metadata
-        if self.options.fields:
-            fields = [s.strip() for s in self.options.fields.split(',')]
-        else:
-            fields = []
         version = metadata['Version']
 
         # When showing all packages, note which are not active:
         if active:
-            if fields:
+            if self.options.fields:
                 active_status = ''
             else:
                 active_status = 'active'
         else:
-            if fields:
+            if self.options.fields:
                 active_status = '*'
             else:
                 active_status = 'non-active'
         if develop:
-            if fields:
+            if self.options.fields:
                 development_status = '! ({})'.format(develop)
             else:
                 development_status = 'development ({})'.format(develop)
         else:
             development_status = installed_by
         status = '{} {}'.format(active_status, development_status)
-        if fields:
+        if self.options.fields:
             print(
                 '{} ({}){} {}'.format(metadata['Name'], version, active_status,
                                       development_status))
@@ -389,11 +399,9 @@ class Yolk(object):
             # Need intelligent justification.
             print(metadata['Name'].ljust(15) + ' - ' + version.ljust(12) +
                   ' - ' + status)
-        if fields:
-            # Only show specific fields, using case-insensitive search.
-            fields = [s.lower() for s in fields]
+        if self.options.fields:
             for field in metadata.keys():
-                if field.lower() in fields:
+                if field.lower() in self.options.fields:
                     print('    {}: {}'.format(field, metadata[field]))
             print()
         elif show_metadata:
@@ -616,27 +624,20 @@ class Yolk(object):
         @param directory: directory to download to
         @type directory: string
 
-        @returns: 0 = success or 1 for failed download
-
         """
-        if not command_successful('svn --version'):
-            print('Do you have subversion installed?', file=sys.stderr)
-            return 1
+        if not command_successful(['svn', '--version']):
+            raise YolkException('Do you have subversion installed?')
         if os.path.exists(directory):
-            print(
-                'Checkout directory exists - {}'.format(directory),
-                file=sys.stderr)
-            return 1
+            raise YolkException(
+                'Checkout directory exists - {}'.format(directory))
         try:
             os.mkdir(directory)
         except OSError as err_msg:
-            print('' + str(err_msg), file=sys.stderr)
-            return 1
+            raise YolkException('' + str(err_msg))
         cwd = os.path.realpath(os.curdir)
         os.chdir(directory)
-        status, _ = run_command('/usr/bin/svn co {}'.format(svn_uri))
+        status, _ = run_command(['svn', 'checkout', svn_uri])
         os.chdir(cwd)
-        return 0
 
     def browse_website(self, browser=None):
         """Launch web browser at project's homepage.
@@ -675,10 +676,19 @@ class Yolk(object):
                                               self.all_versions[0])
 
         if metadata:
-            for key in metadata.keys():
-                if not self.options.fields or (self.options.fields and
-                                               self.options.fields == key):
-                    print('{}: {}'.format(key, metadata[key]))
+            if len(self.options.fields) == 1:
+                try:
+                    print(metadata[self.options.fields[0]])
+                except KeyError:
+                    pass
+            else:
+                for key in metadata.keys():
+                    if (
+                        not self.options.fields or
+                        (self.options.fields and
+                         key.lower() in self.options.fields)
+                    ):
+                        print('{}: {}'.format(key, metadata[key]))
         return 0
 
     def versions_available(self):
@@ -948,8 +958,8 @@ def setup_parser():
 
     group_local.add_argument(
         '-f', '--fields', action='store', default=False,
-        help='show specific metadata fields. '
-             '(use with -m or -M)')
+        help='show specific metadata (comma-separated) fields; '
+             'use with -m or -M')
 
     group_local.add_argument(
         '-d', '--depends', action='store', dest='show_deps',
@@ -1084,6 +1094,12 @@ def _updates(names, pypi, user_installs_only):
                 'all', pkg,
                 yolklib.get_highest_installed(pkg)):
 
+            width = terminal_width()
+            if width:
+                print('\rChecking {}'.format(dist.project_name).ljust(width),
+                      end='',
+                      file=sys.stderr)
+
             (project_name, versions) = pypi.query_versions_pypi(
                 dist.project_name)
         return (pkg, dist, project_name, versions)
@@ -1091,8 +1107,11 @@ def _updates(names, pypi, user_installs_only):
     import multiprocessing
     pool = ThreadPool(multiprocessing.cpu_count())
 
-    for (pkg, dist, project_name, versions) in pool.map(worker_function,
-                                                        names):
+    results = pool.map(worker_function, names)
+
+    print('\r', end='', file=sys.stderr)
+
+    for (pkg, dist, project_name, versions) in results:
         try:
             if (
                 user_installs_only and
@@ -1118,7 +1137,28 @@ def _updates(names, pypi, user_installs_only):
                     yield (project_name, dist.version, newest)
 
 
+def terminal_width():
+    try:
+        import fcntl
+        import termios
+        return struct.unpack(
+            'HHHH',
+            fcntl.ioctl(sys.stderr.fileno(),
+                        termios.TIOCGWINSZ,
+                        struct.pack('HHHH', 0, 0, 0, 0)))[1]
+    except (ImportError, OSError):
+        # ImportError for non-Unix.
+        # OSError for non-TTYs.
+        return None
+
+
 def main():
     """Let's do it."""
-    my_yolk = Yolk()
-    my_yolk.run()
+    try:
+        my_yolk = Yolk()
+        my_yolk.run()
+    except (HTTPException, YolkException) as exception:
+        print(exception, file=sys.stderr)
+        return 1
+    except KeyboardInterrupt:
+        return 1
